@@ -9,11 +9,11 @@
 #' @param sheet The name or index of the sheet to read data from.
 #' @param startRow first row to begin looking for data.  Empty rows at the top of a file are always skipped,
 #' regardless of the value of startRow.
-#' @param colNames If \code{TRUE}, the first row of data will be used as column names.
-#' @param skipEmptyRows If \code{TRUE}, empty rows are skipped else empty rows after the first row containing data
+#' @param colNames If `TRUE`, the first row of data will be used as column names.
+#' @param skipEmptyRows If `TRUE`, empty rows are skipped else empty rows after the first row containing data
 #' will return a row of NAs.
-#' @param rowNames If \code{TRUE}, first column of data will be used as row names.
-#' @param detectDates If \code{TRUE}, attempt to recognise dates and perform conversion.
+#' @param rowNames If `TRUE`, first column of data will be used as row names.
+#' @param detectDates If `TRUE`, attempt to recognise dates and perform conversion.
 #' @param cols A numeric vector specifying which columns in the Excel file to read.
 #' If NULL, all columns are read.
 #' @param rows A numeric vector specifying which rows in the Excel file to read.
@@ -24,8 +24,8 @@
 #' @param namedRegion A named region in the Workbook. If not NULL startRow, rows and cols parameters are ignored.
 #' @param na.strings A character vector of strings which are to be interpreted as NA. Blank cells will be returned as NA.
 #' @param fillMergedCells If TRUE, the value in a merged cell is given to all cells within the merge.
-#' @param skipEmptyCols If \code{TRUE}, empty columns are skipped.
-#' @seealso \code{\link{getNamedRegions}}
+#' @param skipEmptyCols If `TRUE`, empty columns are skipped.
+#' @seealso [getNamedRegions()]
 #' @details Formulae written using writeFormula to a Workbook object will not get picked up by read.xlsx().
 #' This is because only the formula is written and left to be evaluated when the file is opened in Excel.
 #' Opening, saving and closing the file with Excel will resolve this.
@@ -120,8 +120,8 @@ read.xlsx.default <- function(
     sheetselected <- FALSE
   }
   
-  if (!grepl("\\.xlsx$", xlsxFile)) {
-    stop("openxlsx can only read .xlsx files", call. = FALSE)
+  if (!grepl("\\.xlsx|\\.xlsm$", xlsxFile)) {
+    stop("openxlsx can only read .xlsx or .xlsm files", call. = FALSE)
   }
   
   assert_true_false1(colNames)
@@ -139,10 +139,8 @@ read.xlsx.default <- function(
     rows <- as.integer(sort(rows))
   }
   
-  xmlDir <-
-    file.path(tempdir(), paste0(sample(LETTERS, 10), collapse = ""), "_excelXMLRead")
+  xmlDir <- paste0(tempfile(), "_excelXMLRead")
   xmlFiles <- unzip(xlsxFile, exdir = xmlDir)
-  
   on.exit(unlink(xmlDir, recursive = TRUE), add = TRUE)
   
   sharedStringsFile <- grep("sharedStrings.xml$", xmlFiles, perl = TRUE, value = TRUE)
@@ -203,9 +201,8 @@ read.xlsx.default <- function(
       # name, the name will be "'sheet 1'" instead of "sheet 1.
       dn_sheetNames[wsp] <- gsub("^'+|'+$", "\\1", dn_sheetNames[wsp])
     }
-    
     # namedRegion in between 'name="' and '"'
-    dn_namedRegion <- gsub(".*name=\"(\\w+)\".*", "\\1", dn)
+    dn_namedRegion <- gsub(".*name=\"([[:graph:]_]+)\".*", "\\1", dn)
     
     if (length(dn) == 0) {
       warning("Workbook has no named region.")
@@ -563,8 +560,8 @@ read.xlsx.default <- function(
 #' @details Creates a data.frame of all data in worksheet.
 #' @author Alexander Walker
 #' @return data.frame
-#' @seealso \code{\link{getNamedRegions}}
-#' @seealso \code{\link{read.xlsx}}
+#' @seealso [getNamedRegions()]
+#' @seealso [read.xlsx()]
 #' @export
 #' @examples
 #' xlsxFile <- system.file("extdata", "readTest.xlsx", package = "openxlsx")
