@@ -500,7 +500,10 @@ SEXP read_workbook(IntegerVector cols_in,
   
   bool has_strings = true;
   IntegerVector st_inds0 (1);
-  st_inds0[0] = string_inds[0];
+  
+  if (string_inds.size()) 
+    st_inds0[0] = string_inds[0];
+  
   if(is_true(all(is_na(st_inds0))))
     has_strings = false;
   
@@ -549,8 +552,7 @@ SEXP read_workbook(IntegerVector cols_in,
     for(unsigned short i=0; i < nCols; i++){
       
       if(missing_header[i]){  // a missing header element
-        
-	sprintf(&(name[0]), "X%hu", (unsigned short)(i+1));
+        snprintf(&(name[0]), sizeof(name), "X%hu", i+1);
         // sprintf(&(name[0]), "X%u", i+1);
         // snprintf(&(name[0]), sizeof(&(name[0])), "X%d", i+1);
         // snprintf(&(name[0]), 10, "X%d", i+1);
@@ -560,7 +562,8 @@ SEXP read_workbook(IntegerVector cols_in,
         
         col_names[i] = v[pos];
         if(col_names[i] == "NA"){
-	  sprintf(&(name[0]), "X%hu", (unsigned short)(i+1));
+          snprintf(&(name[0]), sizeof(name), "X%hu", i+1);
+          
           // sprintf(&(name[0]), "X%du", i+1);
           // snprintf(&(name[0]), sizeof(&(name[0])), "X%d", i+1);
           // snprintf(&(name[0]), 10, "X%d", i+1);
@@ -620,7 +623,8 @@ SEXP read_workbook(IntegerVector cols_in,
   }else{ // else col_names is FALSE
     char name[6];
     for(int i =0; i < nCols; i++){
-      sprintf(&(name[0]), "X%hu", (unsigned short)(i+1));
+      snprintf(&(name[0]), sizeof(name), "X%hu", i+1);
+      
        // snprintf(&(name[0]), sizeof(&(name[0])), "X%d", i+1);
       // sprintf(&(name[0]), "X%u", i+1);
       col_names[i] = name;
@@ -637,7 +641,7 @@ SEXP read_workbook(IntegerVector cols_in,
   // Possible there are no string_inds to begin with and value of string_inds is 0
   // Possible we have string_inds but they have now all been used up by headers
   bool allNumeric = false;
-  if((string_inds.size() == 0) || (bool) all(is_na(string_inds)))
+  if((string_inds.size() == 0) || is_true(all(is_na(string_inds))))
     allNumeric = true;
   
   if(has_date){
@@ -646,7 +650,7 @@ SEXP read_workbook(IntegerVector cols_in,
   }
   
   // If we have colnames some elements where used to create these -so we remove the corresponding number of elements
-  if(hasColNames && has_date)
+  if(hasColNames & has_date)
     is_date.erase(is_date.begin(), is_date.begin() + pos);
   
   
